<?php

/*
 * manages plugin upgrades
 *
 */
class AitQuickCommentsUpgrade {
	public $options;

	/*
	 * constructor
	 *
	 */
	public function __construct(&$options) {
		$this->options = &$options;
	}

	/*
	 * upgrades if possible otherwise die to avoid activation
	 *
	 */
	public function upgrade_at_activation() {
		if (!$this->can_upgrade()) {
			ob_start();
			die(ob_get_contents());
		}
	}

	/*
	 * upgrades if possible otherwise returns false to stop plugin loading
	 *
	 * @return bool true if upgrade is possible, false otherwise
	 */
	public function upgrade() {
		if (!$this->can_upgrade()) {
			return false;
		}
		return true;
	}


	/*
	 * check if we the previous version is not too old
	 * /!\ never start any upgrade before admin_init as it is likely to conflict with some other plugins
	 *
	 * @return bool true if upgrade is possible, false otherwise
	 */
	public function can_upgrade() {
		// run upgrade only with current skeleton version which contains functionality for plugin pages
		$skeletonVersionOptionKey = "_ait_" . sanitize_key(get_stylesheet()) . "_skeleton_version";
		$skeletonVersion = get_option($skeletonVersionOptionKey, "");
		if (version_compare($skeletonVersion, '2.20.0', '<')) {
			return false;
		}

		add_action('admin_init', array(&$this, '_upgrade'));
		return true;
	}



	/*
	 * upgrades the plugin depending on the previous version
	 *
	 */
	public function _upgrade() {
		foreach (array('3.0') as $version) {
			if (version_compare($this->options['version'], $version, '<')) {
				call_user_func(array(&$this, 'upgrade_' . str_replace('.', '_', $version)));
			}
		}

		$this->options['previous_version'] = $this->options['version']; // remember the previous version of plugin
		$this->options['version'] = AIT_QUICK_COMMENTS_VERSION;
		update_option('ait-quick-comments-plugin', $this->options);
	}



    /*
	 * upgrades if the previous version is < 3.0
	 *
	 */
	protected function upgrade_3_0() {
        global $wpdb;
        $table_name = $wpdb->prefix . 'quickcomments_gdpr_log';

        $charset_collate = $wpdb->get_charset_collate();

		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			id mediumint(11) NOT NULL AUTO_INCREMENT,
			email varchar(255) NOT NULL,
			consented_at timestamp NULL,
			rejected_at timestamp NULL,
			consent text NULL,
			PRIMARY KEY(`ID`)
        ) $charset_collate;";

        $wpdb->query($sql);
	}
}
